# @tinyhttp/logger

[![npm (scoped)](https://img.shields.io/npm/v/@tinyhttp/logger?style=flat-square)](https://npmjs.com/package/@tinyhttp/logger) [![npm](https://img.shields.io/npm/dt/@tinyhttp/logger?style=flat-square)](https://npmjs.com/package/@tinyhttp/logger) [![](https://img.shields.io/badge/website-visit-hotpink?style=flat-square)](https://tinyhttp.v1rtl.site/mw/logger)

Simple HTTP logger for tinyhttp.

## Install

```sh
pnpm i @tinyhttp/logger
```

## API

```ts
import { logger } from '@tinyhttp/logger'
```

### `logger(options)`

Returns the middleware to log HTTP requests.

#### Options

- `methods` - a list of HTTP methods to log. Defaults to `http`'s `METHODS`
- `timestamp.format` - timestamp format. Gets consumed by [dayjs](https://day.js.org) library. If a string specified, used as a format, otherwise just enables it.
- `output.callback` - function that recieves the log generated by the logger.
- `output.color` - property that determines if the logger will generate a message with color. usefull for logging into the console, disable it if logging into file / http / etc...
- `emoji` - enable emojis for HTTP status code. See [http-status-emojis](https://github.com/bendrucker/http-status-emojis/blob/master/index.js) for a full list
- `ip` - log IP address

## Example

```ts
import { App } from '@tinyhttp/app'
import { logger } from '@tinyhttp/logger'

new App()
  .use(
    logger({
      methods: ['GET', 'POST'],
      timestamp: { format: 'HH:mm:ss' },
      output: { callback: console.log, color: false }
    })
  )
  .get('/', (req, res) => res.send('Hello world'))
  .post('/', (req, res) => res.send('Sent POST'))
  .listen(3000)
```

## Alternatives

- [Pino](https://getpino.io) - super fast, all natural json logger.
- [Zoya](https://github.com/WoLfulus/zoya) - Truly highly composable logging utility.
- [Morgan](https://github.com/expressjs/morgan) - HTTP request logger middleware for node.js
- [concurrency-logger](https://github.com/pablosichert/concurrency-logger) - Log HTTP requests/responses separately, visualize their concurrency and report logs/errors in context of a request
- [Volleyball](https://github.com/glebec/volleyball) - Tiny HTTP logger for Express showing asynchronous requests and responses
